/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef DSCAMERASERVICE_H
#define DSCAMERASERVICE_H

#include <QtCore/qobject.h>

#include <qmediaservice.h>

QT_BEGIN_NAMESPACE

class DSCameraControl;
class DSCameraSession;
class DSVideoOutputControl;
class DSVideoDeviceControl;
class DSImageCaptureControl;


class DSCameraService : public QMediaService
{
    Q_OBJECT

public:
    DSCameraService(QObject *parent = 0);
    ~DSCameraService();

    virtual QMediaControl* requestControl(const char *name);
    virtual void releaseControl(QMediaControl *control);

private:
    DSCameraControl        *m_control;
    DSCameraSession        *m_session;
    DSVideoOutputControl   *m_videoOutput;
#if defined(HAVE_WIDGETS)
    QMediaControl          *m_viewFinderWidget;
#endif
    DSVideoDeviceControl   *m_videoDevice;
    QMediaControl          *m_videoRenderer;
    DSImageCaptureControl  *m_imageCapture;
    QByteArray m_device;
};

QT_END_NAMESPACE

#endif
